@@ -25,17 +25,17 @@
 #include <config.h>
 #include "nautilus-throbber.h"
 
-#include <bonobo.h>
-#include <gnome.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libnautilus-extensions/nautilus-debug.h>
-#include <libnautilus-extensions/nautilus-global-preferences.h>
-#include <liboaf/liboaf.h>
+#include <eel/eel-debug.h>
+#include <libgnomeui/gnome-client.h>
+#include <libgnomeui/gnome-ui-init.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <libnautilus-private/nautilus-global-preferences.h>
+#include <string.h>
 
 static int object_count = 0;
 
 static void
-throbber_object_destroyed(GtkObject *obj)
+throbber_object_destroyed (GtkObject *obj)
 {
 	object_count--;
 	if (object_count <= 0) {
@@ -45,8 +45,8 @@ throbber_object_destroyed(GtkObject *obj)
 
 static BonoboObject *
 throbber_make_object (BonoboGenericFactory *factory, 
-			const char *iid, 
-			void *closure)
+		      const char *iid, 
+		      void *closure)
 {
 	NautilusThrobber *throbber;
 	BonoboObject *bonobo_control;
@@ -55,13 +55,14 @@ throbber_make_object (BonoboGenericFactory *factory,
 		return NULL;
 	}
 	
-	throbber = NAUTILUS_THROBBER (gtk_object_new (NAUTILUS_TYPE_THROBBER, NULL));
-
+	throbber = NAUTILUS_THROBBER (g_object_new (NAUTILUS_TYPE_THROBBER, NULL));
+	
 	object_count++;
-
+	
 	bonobo_control = nautilus_throbber_get_control (throbber);
+	
+	g_signal_connect (bonobo_control, "destroy", G_CALLBACK (throbber_object_destroyed), NULL);
 
-	gtk_signal_connect (GTK_OBJECT (bonobo_control), "destroy", throbber_object_destroyed, NULL);
 	return bonobo_control;
 }
 
@@ -69,60 +70,43 @@ int
 main (int argc, char *argv[])
 {
 	BonoboGenericFactory *factory;
-	CORBA_ORB orb;
 	char *registration_id;
 
-	/* Make criticals and warnings stop in the debugger if
-	 * NAUTILUS_DEBUG is set. Unfortunately, this has to be done
-	 * explicitly for each domain.
-	 */
 	if (g_getenv ("NAUTILUS_DEBUG") != NULL) {
-		nautilus_make_warnings_and_criticals_stop_in_debugger
-			(G_LOG_DOMAIN, g_log_domain_glib,
-			 "Bonobo",
-			 "Gdk",
-			 "GnomeUI",
-			 "GnomeVFS",
-			 "GnomeVFS-CORBA",
-			 "GnomeVFS-pthread",
-			 "Gtk",
-			 "Gdk-Pixbuf",
-			 "Nautilus",
-			 "Nautilus-Authenticate",
-			 "Nautilus-Tree",
-			 "ORBit",
-			 NULL);
+		eel_make_warnings_and_criticals_stop_in_debugger ();
 	}
 
+	/* Initialize libraries. */
+	gnome_program_init ("nautilus-throbber",
+			    VERSION,
+			    LIBGNOMEUI_MODULE,
+			    argc, argv,
+			    NULL);
+
+	bonobo_ui_init ("nautilus-throbber", VERSION, &argc, argv);
+
 	/* Disable session manager connection */
-	gnome_client_disable_master_connection ();
+	g_object_set (G_OBJECT (gnome_program_get()),
+	              GNOME_CLIENT_PARAM_SM_CONNECT, FALSE, NULL);
 
-	gnomelib_register_popt_table (oaf_popt_options, oaf_get_popt_table_name ());
-	orb = oaf_init (argc, argv);
+	nautilus_global_preferences_init ();   
 
-	gnome_init ("nautilus-throbber", VERSION, 
-		    argc, argv); 
-
-	gdk_rgb_init ();
-
-	bonobo_init (orb, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL);
-
-	/* initialize gnome-vfs, etc */
-	g_thread_init (NULL);
-	gnome_vfs_init ();
-	nautilus_global_preferences_initialize ();   
-	
-	registration_id = oaf_make_registration_id ("OAFIID:nautilus_throbber_factory", getenv ("DISPLAY"));
-	factory = bonobo_generic_factory_new_multi (registration_id, 
-						    throbber_make_object,
-						    NULL);
+	registration_id = bonobo_activation_make_registration_id ("OAFIID:nautilus_throbber_factory", g_getenv ("DISPLAY"));
+	factory = bonobo_generic_factory_new ("OAFIID:nautilus_throbber_factory", 
+					      throbber_make_object,
+					      NULL);
 	g_free (registration_id);
 
-	
-	do {
-		bonobo_main ();
-	} while (object_count > 0);
+	if (factory != NULL) {
+		bonobo_activate ();
+		do {
+			gtk_main ();
+		} while (object_count > 0);
+		
+		bonobo_object_unref (BONOBO_OBJECT (factory));
+	}
 
-	gnome_vfs_shutdown ();	
-	return 0;
+	gnome_vfs_shutdown ();
+
+	return EXIT_SUCCESS;
 }
