@@ -570,11 +570,7 @@ make_thumbnails (gpointer data)
 			if (nautilus_file_is_mime_type (file, "image/svg")) {
 				thumbnail_path = gnome_vfs_get_local_path_from_uri (info->thumbnail_uri);
 				if (thumbnail_path != NULL) {
-					FILE *f = fopen (thumbnail_path, "rb");
-					if (f != NULL) {
-						full_size_image = rsvg_render_file (f, 1.0);
-						fclose (f);
-					}
+					full_size_image = rsvg_pixbuf_from_file (thumbnail_path, NULL);
 				}
 #ifdef HAVE_LIBJPEG
 			} else if (nautilus_file_is_mime_type (file, "image/jpeg")) {
@@ -593,7 +589,7 @@ make_thumbnails (gpointer data)
 			if (full_size_image != NULL) {													
 				/* scale the content image as necessary */	
 				scaled_image = eel_gdk_pixbuf_scale_down_to_fit (full_size_image, 96, 96);	
-				gdk_pixbuf_unref (full_size_image);
+				g_object_unref (full_size_image);
 				
 				thumbnail_path = gnome_vfs_get_local_path_from_uri (new_thumbnail_uri);
 				if (thumbnail_path == NULL
@@ -601,7 +597,7 @@ make_thumbnails (gpointer data)
 					g_warning ("error saving thumbnail %s", thumbnail_path);
 				}
 				g_free (thumbnail_path);
-				gdk_pixbuf_unref (scaled_image);
+				g_object_unref (scaled_image);
 			} else {
 				/* gdk-pixbuf couldn't load the image, so trying using ImageMagick */
 				char *temp_str;
@@ -679,7 +675,7 @@ pixbuf_is_framed (GdkPixbuf *pixbuf)
  * a frame if necessary
  */
 GdkPixbuf *
-nautilus_thumbnail_load_framed_image (const char *path, gboolean anti_aliased_frame)
+nautilus_thumbnail_load_framed_image (const char *path)
 {
 	GdkPixbuf *pixbuf, *pixbuf_with_frame, *frame;
 	gboolean got_frame_offsets;
@@ -687,7 +683,7 @@ nautilus_thumbnail_load_framed_image (const char *path, gboolean anti_aliased_fr
 	int left_offset, top_offset, right_offset, bottom_offset;
 	char c;
 	
-	pixbuf = gdk_pixbuf_new_from_file (path);
+	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf == NULL || pixbuf_is_framed (pixbuf)) {
 		return pixbuf;
 	}
@@ -696,7 +692,7 @@ nautilus_thumbnail_load_framed_image (const char *path, gboolean anti_aliased_fr
 	 * an old Nautilus), so we must embed it in a frame.
 	 */
 
-	frame = nautilus_icon_factory_get_thumbnail_frame (anti_aliased_frame);
+	frame = nautilus_icon_factory_get_thumbnail_frame ();
 	if (frame == NULL) {
 		return pixbuf;
 	}
@@ -721,6 +717,6 @@ nautilus_thumbnail_load_framed_image (const char *path, gboolean anti_aliased_fr
 	pixbuf_with_frame = eel_embed_image_in_frame
 		(pixbuf, frame,
 		 left_offset, top_offset, right_offset, bottom_offset);
-	gdk_pixbuf_unref (pixbuf);	
+	g_object_unref (pixbuf);	
 	return pixbuf_with_frame;
 }
