@@ -38,6 +38,8 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-i18n.h>
+#include <libgnomeui/gnome-client.h>
+#include <libgnomeui/gnome-ui-init.h>
 #include <libgnomevfs/gnome-vfs-init.h>
 #include <stdlib.h>
 #include <string.h>
@@ -59,7 +61,7 @@ delayed_quit_timeout_callback (gpointer data)
 
 	callback_data = (CallbackData *) data;
 	callback_data->delayed_quit_timeout_id = 0;
-	bonobo_main_quit ();
+	gtk_main_quit ();
 
 	return FALSE;
 }
@@ -163,9 +165,7 @@ nautilus_view_standard_main_multi (const char *executable_name,
 {
 	BonoboGenericFactory *factory;
 	CallbackData callback_data;
-#ifdef GNOME2_CONVERSION_COMPLETE
 	char *registration_id;
-#endif
 
 	g_return_val_if_fail (executable_name != NULL, EXIT_FAILURE);
 	g_return_val_if_fail (version != NULL, EXIT_FAILURE);
@@ -193,20 +193,18 @@ nautilus_view_standard_main_multi (const char *executable_name,
 	}
 #endif
 
-#if GNOME2_CONVERSION_COMPLETE
-	/* Disable session manager connection */
-	gnome_client_disable_master_connection ();
-#endif
-
-#if GNOME2_CONVERSION_COMPLETE
-	gnomelib_register_popt_table (bonobo_activation_popt_options, bonobo_activation_get_popt_table_name ());
-#endif
 	/* Initialize libraries. */
-	g_thread_init (NULL);
-	gnome_vfs_init ();
-
+	gnome_program_init (executable_name, version,
+			    LIBGNOMEUI_MODULE,
+			    argc, argv,
+			    NULL);
+	
 	bonobo_ui_init (executable_name, version, &argc, argv);
 
+	/* Disable session manager connection */
+	g_object_set (G_OBJECT (gnome_program_get()),
+	              GNOME_CLIENT_PARAM_SM_CONNECT, FALSE, NULL);
+
 	if (post_initialize_callback != NULL) {
 		(* post_initialize_callback) ();
 	}
@@ -219,26 +217,18 @@ nautilus_view_standard_main_multi (const char *executable_name,
 	callback_data.delayed_quit_timeout_id = 0;
 
 	/* Create the factory. */
-
-#ifdef GNOME2_CONVERSION_COMPLETE
-        registration_id = bonobo_activation_make_registration_id (factory_iid, 
-						    DisplayString (GDK_DISPLAY ()));
-#endif
-
-	factory = bonobo_generic_factory_new (factory_iid, 
+        registration_id = bonobo_activation_make_registration_id (factory_iid, DisplayString (gdk_display));
+	factory = bonobo_generic_factory_new (registration_id, 
 					      make_object,
 					      &callback_data);
-#ifdef GNOME2_CONVERSION_COMPLETE
 	g_free (registration_id);
-#endif
 
 	if (factory != NULL) {
 		/* Loop until we have no more objects. */
+		bonobo_activate ();
 		do {
-			bonobo_main ();
+			gtk_main ();
 		} while (callback_data.object_count > 0 || callback_data.delayed_quit_timeout_id != 0);
-		
-		/* Let the factory go. */
 		bonobo_object_unref (BONOBO_OBJECT (factory));
 	}
 
@@ -330,4 +320,3 @@ nautilus_view_create_from_get_type_function (const char *iid, void *user_data)
 {
 	return NAUTILUS_VIEW (g_object_new (((TypeFunc) (user_data)) (), NULL));
 }
-
