@@ -34,24 +34,22 @@
 #include <config.h>
 #include "nautilus-location-bar.h"
 
-#include "nautilus-window.h"
 #include "nautilus-window-private.h"
+#include "nautilus-window.h"
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-stock-dialogs.h>
+#include <eel/eel-string.h>
+#include <eel/eel-vfs-extensions.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtksignal.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-mime.h>
-#include <libgnomeui/gnome-stock.h>
+#include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
+#include <libnautilus-private/nautilus-entry.h>
 #include <libnautilus/nautilus-clipboard.h>
-#include <libnautilus-extensions/nautilus-entry.h>
-#include <libnautilus-extensions/nautilus-file-utilities.h>
-#include <libnautilus-extensions/nautilus-glib-extensions.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
-#include <libnautilus-extensions/nautilus-stock-dialogs.h>
-#include <libnautilus-extensions/nautilus-string.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -66,7 +64,7 @@ static const char untranslated_go_to_label[] = N_("Go To:");
 
 struct NautilusLocationBarDetails {
 	GtkLabel *label;
-	GtkEntry *entry;
+	NautilusEntry *entry;
 	
 	char *last_location;
 	
@@ -99,11 +97,11 @@ static GtkTargetEntry drop_types [] = {
 static char *nautilus_location_bar_get_location     (NautilusNavigationBar    *navigation_bar); 
 static void  nautilus_location_bar_set_location     (NautilusNavigationBar    *navigation_bar,
 						     const char               *location);
-static void  nautilus_location_bar_initialize_class (NautilusLocationBarClass *class);
-static void  nautilus_location_bar_initialize       (NautilusLocationBar      *bar);
+static void  nautilus_location_bar_class_init (NautilusLocationBarClass *class);
+static void  nautilus_location_bar_init       (NautilusLocationBar      *bar);
 static void  nautilus_location_bar_update_label     (NautilusLocationBar      *bar);
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusLocationBar,
+EEL_CLASS_BOILERPLATE (NautilusLocationBar,
 				   nautilus_location_bar,
 				   NAUTILUS_TYPE_NAVIGATION_BAR)
 
@@ -135,7 +133,11 @@ drag_data_received_callback (GtkWidget *widget,
 	g_assert (data != NULL);
 	g_assert (callback_data == NULL);
 
+#if GNOME2_CONVERSION_COMPLETE
 	names = gnome_uri_list_extract_uris (data->data);
+#else
+	names = NULL;
+#endif
 
 	if (names == NULL) {
 		g_warning ("No D&D URI's");
@@ -153,13 +155,12 @@ drag_data_received_callback (GtkWidget *widget,
 		prompt = g_strdup_printf (_("Do you want to view these %d locations "
 					  "in separate windows?"), 
 					  name_count);
-		new_windows_for_extras = nautilus_run_simple_dialog 
+		new_windows_for_extras = eel_run_simple_dialog 
 			(GTK_WIDGET (nautilus_location_bar_get_window (widget)),
 			 TRUE,
 			 prompt,
 			 _("View in Multiple Windows?"),
-			 GNOME_STOCK_BUTTON_OK,
-			 GNOME_STOCK_BUTTON_CANCEL,
+			 GTK_STOCK_OK, GTK_STOCK_CANCEL,
 			 NULL) == GNOME_OK;
 
 		g_free (prompt);
@@ -182,7 +183,9 @@ drag_data_received_callback (GtkWidget *widget,
 		}
 	}
 						  
+#if GNOME2_CONVERSION_COMPLETE
 	gnome_uri_list_free_strings (names);
+#endif
 
 	gtk_drag_finish (context, TRUE, FALSE, time);
 }
@@ -210,7 +213,7 @@ drag_data_get_callback (GtkWidget *widget,
 		gtk_selection_data_set (selection_data,
 					selection_data->target,
 					8, (guchar *) entry_text,
-					nautilus_strlen (entry_text));
+					eel_strlen (entry_text));
 		break;
 	default:
 		g_assert_not_reached ();
@@ -227,6 +230,7 @@ drag_data_get_callback (GtkWidget *widget,
 static void
 style_set_handler (GtkWidget *widget, GtkStyle *previous_style)
 {
+#if GNOME2_CONVERSION_COMPLETE
 	int width;
 
 	width = gdk_string_width (widget->style->font, GO_TO_LABEL);
@@ -235,8 +239,11 @@ style_set_handler (GtkWidget *widget, GtkStyle *previous_style)
 	width += 2 * GTK_MISC (widget)->xpad;
 	
 	gtk_widget_set_usize (widget, width, -1);
+#endif
 }
 
+#if GNOME2_CONVERSION_COMPLETE
+
 /* utility routine to determine the string to expand to.  If we don't have anything yet, accept
    the whole string, otherwise accept the largest part common to both */
 
@@ -249,7 +256,7 @@ accumulate_name(char *full_name, char *candidate_name)
 		result_name = g_strdup (candidate_name);
 	else {
 		result_name = full_name;
-		if (!nautilus_str_has_prefix (full_name, candidate_name)) {
+		if (!eel_str_has_prefix (full_name, candidate_name)) {
 			str1 = full_name;
 			str2 = candidate_name;
 			while ((*str1++ == *str2++)) { }
@@ -265,7 +272,7 @@ static void
 get_file_info_list (NautilusLocationBar *bar, const char* dir_name)
 {
 	GnomeVFSResult result;
-	if (nautilus_strcmp (bar->details->current_directory, dir_name) != 0) {
+	if (eel_strcmp (bar->details->current_directory, dir_name) != 0) {
 		g_free (bar->details->current_directory);
 		if (bar->details->file_info_list) {
 			gnome_vfs_file_info_list_free (bar->details->file_info_list);	
@@ -274,7 +281,7 @@ get_file_info_list (NautilusLocationBar *bar, const char* dir_name)
 		
 		bar->details->current_directory = g_strdup (dir_name);
 		result = gnome_vfs_directory_list_load (&bar->details->file_info_list, dir_name,
-							GNOME_VFS_FILE_INFO_DEFAULT, NULL);
+							GNOME_VFS_FILE_INFO_DEFAULT);
 		if (result != GNOME_VFS_OK) {
 			if (bar->details->file_info_list) {
 				gnome_vfs_file_info_list_free (bar->details->file_info_list);	
@@ -301,7 +308,7 @@ try_to_expand_path (gpointer callback_data)
 	uint base_length;
 	int current_path_length;
 	int offset;
-	const char *base_name_ptr;
+	char *base_name_uri_escaped;
 	char *base_name;
 	char *user_location;
 	char *current_path;
@@ -316,14 +323,14 @@ try_to_expand_path (gpointer callback_data)
 	bar->details->idle_id = 0;
 	
 	/* if it's just '~' or '~/', don't expand because slash shouldn't be appended */
-	if (nautilus_strcmp (user_location, "~") == 0
-	    || nautilus_strcmp (user_location, "~/") == 0) {
+	if (eel_strcmp (user_location, "~") == 0
+	    || eel_strcmp (user_location, "~/") == 0) {
 		g_free (user_location);
 		return FALSE;
 	}
-	current_path = nautilus_make_uri_from_input (user_location);
+	current_path = eel_make_uri_from_input (user_location);
 
-	if (!nautilus_istr_has_prefix (current_path, "file://")) {
+	if (!eel_istr_has_prefix (current_path, "file://")) {
 		g_free (user_location);
 		g_free (current_path);
 		return FALSE;
@@ -336,12 +343,13 @@ try_to_expand_path (gpointer callback_data)
 
 	uri = gnome_vfs_uri_new (current_path);
 	
-	base_name_ptr = gnome_vfs_uri_get_basename (uri);
-	if (base_name_ptr == NULL) {
+	base_name_uri_escaped = gnome_vfs_uri_extract_short_name (uri);
+	if (base_name_uri_escaped == NULL) {
 		base_name = NULL;
 	} else {
-		base_name = gnome_vfs_unescape_string (base_name_ptr, NULL);
+		base_name = gnome_vfs_unescape_string (base_name_uri_escaped, NULL);
 	}
+	g_free (base_name_uri_escaped);
 
 	if (base_name == NULL) {
 		gnome_vfs_uri_unref (uri);
@@ -368,7 +376,7 @@ try_to_expand_path (gpointer callback_data)
 	expand_text = NULL;
 	for (element = bar->details->file_info_list; element != NULL; element = element->next) {
 		current_file_info = element->data;
-		if (nautilus_str_has_prefix (current_file_info->name, base_name)) {
+		if (eel_str_has_prefix (current_file_info->name, base_name)) {
 			if (current_file_info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
 				expand_name = g_strconcat (current_file_info->name, "/", NULL);
 			} else {
@@ -381,7 +389,7 @@ try_to_expand_path (gpointer callback_data)
 	
 	/* if we've got something, add it to the entry */	
 	if (expand_text != NULL
-	    && !nautilus_str_has_suffix (current_path, expand_text)
+	    && !eel_str_has_suffix (current_path, expand_text)
 	    && base_length < strlen (expand_text)) {
 		gtk_entry_append_text (GTK_ENTRY (editable), expand_text + base_length);
 		gtk_entry_select_region (GTK_ENTRY (editable),
@@ -469,11 +477,11 @@ static gboolean
 position_and_selection_are_at_end (GtkEditable *editable)
 {
 	int end;
+	int start_sel, end_sel;
 	
 	end = get_editable_length (editable);
-	if (editable->has_selection) {
-		if ((int) editable->selection_start_pos != end
-		    || (int) editable->selection_end_pos == end) {
+	if (gtk_editable_get_selection_bounds (editable, &start_sel, &end_sel)) {
+		if (start_sel != end || end_sel != end) {
 			return FALSE;
 		}
 	}
@@ -514,7 +522,8 @@ editable_key_press_callback (GtkObject *object,
 	 * you can't move through the text a character at a
 	 * time. Seems like a bad idea.
 	 */
-	if (event->keyval == GDK_Right && editable->has_selection) {
+	if ((event->keyval == GDK_Right || event->keyval == GDK_End)
+	    && gtk_editable_get_selection_bounds (editable, NULL, NULL)) {
 		set_position_and_selection_to_end (editable);
 	}
 
@@ -558,6 +567,7 @@ editable_key_press_callback (GtkObject *object,
 
 	nautilus_location_bar_update_label (bar);
 }
+#endif
 
 static void
 real_activate (NautilusNavigationBar *navigation_bar)
@@ -566,8 +576,23 @@ real_activate (NautilusNavigationBar *navigation_bar)
 
 	bar = NAUTILUS_LOCATION_BAR (navigation_bar);
 
-	/* Put the keyboard focus in the text field when switching to this mode */
+	/* Put the keyboard focus in the text field when switching to this mode,
+	 * and select all text for easy overtyping 
+	 */
 	gtk_widget_grab_focus (GTK_WIDGET (bar->details->entry));
+	nautilus_entry_select_all (bar->details->entry);
+}
+
+static void
+finalize (GObject *object)
+{
+	NautilusLocationBar *bar;
+
+	bar = NAUTILUS_LOCATION_BAR (object);
+
+	g_free (bar->details);
+
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -580,26 +605,32 @@ destroy (GtkObject *object)
 	/* cancel the pending idle call, if any */
 	if (bar->details->idle_id != 0) {
 		gtk_idle_remove (bar->details->idle_id);
+		bar->details->idle_id = 0;
 	}
 	
 	if (bar->details->file_info_list) {
 		gnome_vfs_file_info_list_free (bar->details->file_info_list);	
-	
+		bar->details->file_info_list = NULL;
 	}
 	
 	g_free (bar->details->current_directory);
+	bar->details->current_directory = NULL;
 	
 	g_free (bar->details->last_location);
-	g_free (bar->details);
+	bar->details->last_location = NULL;
 	
-	NAUTILUS_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
-nautilus_location_bar_initialize_class (NautilusLocationBarClass *class)
+nautilus_location_bar_class_init (NautilusLocationBarClass *class)
 {
+	GObjectClass *gobject_class;
 	GtkObjectClass *object_class;
 	NautilusNavigationBarClass *navigation_bar_class;
+
+	gobject_class = G_OBJECT_CLASS (class);
+	gobject_class->finalize = finalize;
 	
 	object_class = GTK_OBJECT_CLASS (class);
 	object_class->destroy = destroy;
@@ -612,7 +643,7 @@ nautilus_location_bar_initialize_class (NautilusLocationBarClass *class)
 }
 
 static void
-nautilus_location_bar_initialize (NautilusLocationBar *bar)
+nautilus_location_bar_init (NautilusLocationBar *bar)
 {
 	GtkWidget *label;
 	GtkWidget *entry;
@@ -630,18 +661,21 @@ nautilus_location_bar_initialize (NautilusLocationBar *bar)
 	gtk_container_add   (GTK_CONTAINER (event_box), label);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
 	gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
-	gtk_signal_connect (GTK_OBJECT (label), "style_set", 
-			    style_set_handler, NULL);
+	g_signal_connect (label, "style_set", 
+			    G_CALLBACK (style_set_handler), NULL);
 
 	gtk_box_pack_start  (GTK_BOX (hbox), event_box, FALSE, TRUE,
 			     GNOME_PAD_SMALL);
 
 	entry = nautilus_entry_new ();
-	NAUTILUS_ENTRY (entry)->special_tab_handling = TRUE;
+
+	nautilus_entry_set_special_tab_handling (NAUTILUS_ENTRY (entry), TRUE);
 	
 	gtk_signal_connect_object (GTK_OBJECT (entry), "activate",
-				   nautilus_navigation_bar_location_changed, GTK_OBJECT (bar));
+				   G_CALLBACK (nautilus_navigation_bar_location_changed),
+				   GTK_OBJECT (bar));
 
+#if GNOME2_CONVERSION_COMPLETE
 	/* The callback uses the marshal interface directly
 	 * so it can both read and write the return value.
 	 */
@@ -649,6 +683,7 @@ nautilus_location_bar_initialize (NautilusLocationBar *bar)
 				 NULL, editable_key_press_callback,
 				 bar, NULL,
 				 FALSE, TRUE);
+#endif
 	
 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
 
@@ -658,25 +693,25 @@ nautilus_location_bar_initialize (NautilusLocationBar *bar)
 	/* Drag source */
 	gtk_drag_source_set (GTK_WIDGET (event_box), 
 			     GDK_BUTTON1_MASK | GDK_BUTTON3_MASK,
-			     drag_types, NAUTILUS_N_ELEMENTS (drag_types),
+			     drag_types, G_N_ELEMENTS (drag_types),
 			     GDK_ACTION_LINK);
 	gtk_signal_connect  (GTK_OBJECT (event_box), "drag_data_get",
-			     GTK_SIGNAL_FUNC (drag_data_get_callback),
+			     G_CALLBACK (drag_data_get_callback),
 			     bar);
 
 	/* Drag dest. */
 	gtk_drag_dest_set  (GTK_WIDGET (bar),
 			    GTK_DEST_DEFAULT_ALL,
-			    drop_types, NAUTILUS_N_ELEMENTS (drop_types),
+			    drop_types, G_N_ELEMENTS (drop_types),
 			    GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK);
-	gtk_signal_connect (GTK_OBJECT (bar), "drag_data_received",
-			    GTK_SIGNAL_FUNC (drag_data_received_callback),
+	g_signal_connect (bar, "drag_data_received",
+			    G_CALLBACK (drag_data_received_callback),
 			    NULL);
 
 	gtk_widget_show_all (hbox);
 
 	bar->details->label = GTK_LABEL (label);
-	bar->details->entry = GTK_ENTRY (entry);	
+	bar->details->entry = NAUTILUS_ENTRY (entry);	
 }
 
 
@@ -705,7 +740,6 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
 	NautilusLocationBar *bar;
 	char *formatted_location;
 
-
 	g_assert (location != NULL);
 	
 	bar = NAUTILUS_LOCATION_BAR (navigation_bar);
@@ -713,21 +747,17 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
 	/* Note: This is called in reaction to external changes, and 
 	 * thus should not emit the LOCATION_CHANGED signal.*/
 	
-	formatted_location = nautilus_format_uri_for_display (location);
+	formatted_location = eel_format_uri_for_display (location);
 	nautilus_entry_set_text (NAUTILUS_ENTRY (bar->details->entry),
 				 formatted_location);
 	g_free (formatted_location);
 
 	/* free up the cached file info from the previous location */
-	if (bar->details->current_directory) {
-		g_free (bar->details->current_directory);
-		bar->details->current_directory = NULL;
-	}
+	g_free (bar->details->current_directory);
+	bar->details->current_directory = NULL;
 	
-	if (bar->details->file_info_list) {
-		gnome_vfs_file_info_list_free (bar->details->file_info_list);	
-		bar->details->file_info_list = NULL;			
-	}
+	gnome_vfs_file_info_list_free (bar->details->file_info_list);	
+	bar->details->file_info_list = NULL;			
 	
 	/* remember the original location for later comparison */
 	
@@ -744,7 +774,7 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
  * @bar: A NautilusLocationBar.
  *
  * returns a newly allocated "string" containing the mangled
- * (by nautilus_make_uri_from_input) text that the user typed in...maybe a URI 
+ * (by eel_make_uri_from_input) text that the user typed in...maybe a URI 
  * but not guaranteed.
  *
  **/
@@ -757,7 +787,7 @@ nautilus_location_bar_get_location (NautilusNavigationBar *navigation_bar)
 	bar = NAUTILUS_LOCATION_BAR (navigation_bar);
 	
 	user_location = gtk_editable_get_chars (GTK_EDITABLE (bar->details->entry), 0, -1);
-	best_uri = nautilus_make_uri_from_input (user_location);
+	best_uri = eel_make_uri_from_input (user_location);
 	g_free (user_location);
 	return best_uri;
 }
@@ -771,12 +801,13 @@ nautilus_location_bar_get_location (NautilusNavigationBar *navigation_bar)
 static void
 nautilus_location_bar_update_label (NautilusLocationBar *bar)
 {
-	char *current_text, *current_location;
+	const char *current_text;
+	char *current_location;
 	
 	current_text = gtk_entry_get_text (GTK_ENTRY (bar->details->entry));
-	current_location = nautilus_make_uri_from_input (current_text);
+	current_location = eel_make_uri_from_input (current_text);
 	
-	if (nautilus_uris_match (bar->details->last_location, current_location)) {
+	if (eel_uris_match (bar->details->last_location, current_location)) {
 		gtk_label_set_text (GTK_LABEL (bar->details->label), LOCATION_LABEL);
 	} else {		 
 		gtk_label_set_text (GTK_LABEL (bar->details->label), GO_TO_LABEL);
